@@ -226,7 +226,7 @@ class Authenticator(httpx.Auth):
                    f"add attribute: {attr}.")
             logger.error(msg)
             raise AttributeError(msg)
-                                 
+
         if self._apply_test_convert:
             value = test_convert(attr, value)
         object.__setattr__(self, attr, value)
@@ -315,6 +315,8 @@ class Authenticator(httpx.Auth):
                    username: str,
                    password: str,
                    locale: Union[str, "Locale"],
+                   serial: Optional[str] = None,
+                   with_username: bool = False,
                    register: bool = False,
                    captcha_callback: Optional[Callable[[str], str]] = None,
                    otp_callback: Optional[Callable[[], str]] = None,
@@ -325,11 +327,18 @@ class Authenticator(httpx.Auth):
 
         .. versionadded:: v0.5.0
 
+        .. versionadded:: v0.5.4
+           The serial argument
+           The with_username argument
+
         Args:
             username: The Amazon email address.
             password: The Amazon password.
             locale: The ``country_code`` or :class:`audible.localization.Locale`
                 instance for the marketplace to login.
+            serial: The device serial. If ``None`` a custom one will be created.
+            with_username: If ``True`` login with Audible username instead 
+                of Amazon account.
             register: If ``True``, register a new device after login.
             captcha_callback: A custom callback to handle captcha requests
                 during login.
@@ -348,6 +357,8 @@ class Authenticator(httpx.Auth):
         auth.re_login(
             username=username,
             password=password,
+            serial=serial,
+            with_username=with_username,
             captcha_callback=captcha_callback,
             otp_callback=otp_callback,
             cvf_callback=cvf_callback,
@@ -356,7 +367,7 @@ class Authenticator(httpx.Auth):
         logger.info(f"logged in to Audible as {username}")
 
         if register:
-            auth.register_device()
+            auth.register_device(serial=serial)
             logger.info("registered Audible device")
 
         return auth
@@ -364,17 +375,27 @@ class Authenticator(httpx.Auth):
     @classmethod
     def from_login_external(cls,
                             locale: Union[str, "Locale"],
+                            serial: Optional[str] = None,
                             register: bool = False,
-                            login_url_callback: Optional[Callable[[str], str]] = None
-                           ) -> "Authenticator":
+                            with_username: bool = False,
+                            login_url_callback: Optional[
+                                Callable[[str], str]] = None
+                            ) -> "Authenticator":
         """Instantiate a new Authenticator from login with external browser.
 
         .. versionadded:: v0.5.1
+        
+        .. versionadded:: v0.5.4
+           The serial argument
+           The with_username argument
 
         Args:
             locale: The ``country_code`` or :class:`audible.localization.Locale`
                 instance for the marketplace to login.
+            serial: The device serial. If ``None`` a custom one will be created.
             register: If ``True``, register a new device after login.
+            with_username: If ``True`` login with Audible username instead 
+                of Amazon account.
             login_url_callback: A custom Callable for handling login with 
                 external browsers.
 
@@ -384,12 +405,15 @@ class Authenticator(httpx.Auth):
         auth = cls()
         auth.locale = locale
 
-        auth.re_login_external(login_url_callback=login_url_callback)
+        auth.re_login_external(
+            serial=serial,
+            with_username=with_username,
+            login_url_callback=login_url_callback)
 
         logger.info("logged in to Audible.")
 
         if register:
-            auth.register_device()
+            auth.register_device(serial=serial)
             logger.info("registered Audible device")
 
         return auth
@@ -545,10 +569,16 @@ class Authenticator(httpx.Auth):
     def re_login(self,
                  username: str,
                  password: str,
+                 serial: Optional[str] = None,
+                 with_username: bool = False,
                  captcha_callback: Optional[Callable[[str], str]] = None,
                  otp_callback: Optional[Callable[[], str]] = None,
                  cvf_callback: Optional[Callable[[], str]] = None,
-                 approval_callback: Optional[Callable[[], Any]] = None) -> None:
+                 approval_callback: Optional[
+                     Callable[[], Any]] = None) -> None:
+
+        if serial is None and self.device_info:
+            serial = self.device_info.get("device_serial_number")
 
         login_device = login(
             username=username,
@@ -556,38 +586,64 @@ class Authenticator(httpx.Auth):
             country_code=self.locale.country_code,
             domain=self.locale.domain,
             market_place_id=self.locale.market_place_id,
+            serial=serial,
+            with_username=with_username,
             captcha_callback=captcha_callback,
             otp_callback=otp_callback,
             cvf_callback=cvf_callback,
             approval_callback=approval_callback)
 
+        serial = login_device.pop("serial")
+        if self.device_info is None:
+            self.device_info = {"device_serial_number": serial}
+
         self._update_attrs(**login_device)
 
     def re_login_external(self,
-                          login_url_callback: Optional[Callable[[str], str]] = None
-                         ) -> None:
+                          serial: Optional[str] = None,
+                          with_username: bool = False,
+                          login_url_callback: Optional[
+                              Callable[[str], str]] = None
+                          ) -> None:
         """Re-login with a external browser and refreshs the access token.
 
         .. versionadded:: v0.5.1
+        
+        .. versionadded:: v0.5.4
+           The serial argument
+           The with_username argument
 
         Args:
-            locale: The ``country_code`` or :class:`audible.localization.Locale`
-                instance for the marketplace to login.
-            register: If ``True``, register a new device after login.
-            login_url_callback: A custom Callable for handling login with 
+            serial: The device serial. If ``None`` a custom one will be created.
+            with_username: If ``True`` login with Audible username instead 
+                of Amazon account.
+            login_url_callback: A custom Callable for handling login with
                 external browsers.
         """
+        if serial is None and self.device_info:
+            serial = self.device_info.get("device_serial_number")
+
         login_device = external_login(
             country_code=self.locale.country_code,
             domain=self.locale.domain,
             market_place_id=self.locale.market_place_id,
+            serial=serial,
+            with_username=with_username,
             login_url_callback=login_url_callback)
 
+        serial = login_device.pop("serial")
+        if self.device_info is None:
+            self.device_info = {"device_serial_number": serial}
+
         self._update_attrs(**login_device)
 
-    def register_device(self) -> None:
+    def register_device(self, serial: Optional[str] = None) -> None:
+        if serial is None and self.device_info:
+            serial = self.device_info.get("device_serial_number")
+
         register_device = register_(
-            access_token=self.access_token, domain=self.locale.domain)
+            access_token=self.access_token, domain=self.locale.domain,
+            serial=serial)
 
         self._update_attrs(**register_device)
 
@@ -640,12 +696,13 @@ class Authenticator(httpx.Auth):
 
         """
         if not force_refresh and extract and self.activation_bytes is not None:
-            logger.debug(f"Activation bytes already fetched. Returned saved one.")
+            logger.debug(
+                f"Activation bytes already fetched. Returned saved one.")
             return self.activation_bytes
 
         logger.debug("Fetch activation blob from server now.")
         ab = get_ab(self, filename, extract)
-        
+
         if extract:
             logger.debug("Extract activation bytes from blob and store value"
                          "activation_bytes attribute.")
@@ -684,9 +741,13 @@ class LoginAuthenticator:
                 otp_callback: Optional[Callable[[], str]] = None,
                 cvf_callback: Optional[Callable[[], str]] = None
                 ) -> "Authenticator":
-        return Authenticator.from_login(username, password, locale, register,
-                                        captcha_callback, otp_callback,
-                                        cvf_callback)
+        return Authenticator.from_login(username=username,
+                                        password=password,
+                                        locale=locale,
+                                        register=register,
+                                        captcha_callback=captcha_callback,
+                                        otp_callback=otp_callback,
+                                        cvf_callbac=cvf_callback)
 
 
 class FileAuthenticator:
@@ -703,5 +764,8 @@ class FileAuthenticator:
                 locale: Optional[Union[str, "Locale"]] = None,
                 encryption: Optional[Union[bool, str]] = None,
                 **kwargs) -> "Authenticator":
-        return Authenticator.from_file(filename, password, locale, encryption,
+        return Authenticator.from_file(filename=filename,
+                                       password=password,
+                                       locale=locale,
+                                       encryption=encryption,
                                        **kwargs)
