@@ -1,6 +1,6 @@
 import uuid
 from datetime import datetime, timedelta
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 import httpx
 
@@ -11,10 +11,12 @@ def get_random_device_serial() -> str:
     Using a random serial prevents from unregister devices by other users
     with same `device_serial`.
     """
-    return str(uuid.uuid4()).replace("-", "")
+    return uuid.uuid4().hex
 
 
-def register(access_token: str, domain: str) -> Dict[str, Any]:
+def register(access_token: str,
+             domain: str,
+             serial: Optional[str] = None) -> Dict[str, Any]:
     """Registers a dummy Audible device. 
 
     Args:
@@ -37,7 +39,7 @@ def register(access_token: str, domain: str) -> Dict[str, Any]:
             "app_version":
                 "3.26.1",
             "device_serial":
-                get_random_device_serial(),
+                serial or get_random_device_serial(),
             "device_type":
                 "A2CZJZGLK2JJVM",
             "device_name": (
